@@ -1,7 +1,7 @@
 /*
  * vim:ts=4:sw=4:expandtab
  *
- * i3 - an improved dynamic tiling window manager
+ * i3 - an improved tiling window manager
  * © 2009 Michael Stapelberg and contributors (see also: LICENSE)
  *
  * i3-nagbar is a utility which displays a nag message, for example in the case
@@ -126,9 +126,11 @@ static void start_application(const char *command) {
 }
 
 static button_t *get_button_at(int16_t x, int16_t y) {
-    for (int c = 0; c < buttoncnt; c++)
-        if (x >= (buttons[c].x) && x <= (buttons[c].x + buttons[c].width))
+    for (int c = 0; c < buttoncnt; c++) {
+        if (x >= (buttons[c].x) && x <= (buttons[c].x + buttons[c].width)) {
             return &buttons[c];
+        }
+    }
 
     return NULL;
 }
@@ -148,11 +150,13 @@ static void handle_button_release(xcb_connection_t *conn, xcb_button_release_eve
     printf("button released on x = %d, y = %d\n",
            event->event_x, event->event_y);
     /* If the user hits the close button, we exit(0) */
-    if (event->event_x >= btn_close.x && event->event_x < btn_close.x + btn_close.width)
+    if (event->event_x >= btn_close.x && event->event_x < btn_close.x + btn_close.width) {
         exit(0);
+    }
     button_t *button = get_button_at(event->event_x, event->event_y);
-    if (!button)
+    if (!button) {
         return;
+    }
 
     /* We need to create a custom script containing our actual command
      * since not every terminal emulator which is contained in
@@ -266,13 +270,9 @@ static int handle_expose(xcb_connection_t *conn, xcb_expose_event_t *event) {
 }
 
 /**
- * Return the position and size the i3-nagbar window should use.
- * This will be the primary output or a fallback if it cannot be determined.
+ * Tries to position the rectangle on the primary output.
  */
-static xcb_rectangle_t get_window_position(void) {
-    /* Default values if we cannot determine the primary output or its CRTC info. */
-    xcb_rectangle_t result = (xcb_rectangle_t){50, 50, 500, font.height + 2 * MSG_PADDING + BAR_BORDER};
-
+static void set_window_position_primary(xcb_rectangle_t *result) {
     xcb_randr_get_screen_resources_current_cookie_t rcookie = xcb_randr_get_screen_resources_current(conn, root);
     xcb_randr_get_output_primary_cookie_t pcookie = xcb_randr_get_output_primary(conn, root);
 
@@ -314,14 +314,61 @@ static xcb_rectangle_t get_window_position(void) {
         goto free_resources;
     }
 
-    result.x = crtc->x;
-    result.y = crtc->y;
+    result->x = crtc->x;
+    result->y = crtc->y;
     goto free_resources;
 
 free_resources:
     free(res);
     free(primary);
-    return result;
+}
+
+/**
+ * Tries to position the rectangle on the output with input focus.
+ * If unsuccessful, try to position on primary output.
+ */
+static void set_window_position_focus(xcb_rectangle_t *result) {
+    bool success = false;
+    xcb_get_input_focus_reply_t *input_focus = NULL;
+    xcb_get_geometry_reply_t *geometry = NULL;
+    xcb_translate_coordinates_reply_t *coordinates = NULL;
+
+    /* To avoid the input window disappearing while determining its position */
+    xcb_grab_server(conn);
+
+    input_focus = xcb_get_input_focus_reply(conn, xcb_get_input_focus(conn), NULL);
+    if (input_focus == NULL || input_focus->focus == XCB_NONE) {
+        LOG("Failed to receive the current input focus or no window has the input focus right now.\n");
+        goto free_resources;
+    }
+
+    geometry = xcb_get_geometry_reply(conn, xcb_get_geometry(conn, input_focus->focus), NULL);
+    if (geometry == NULL) {
+        LOG("Failed to received window geometry.\n");
+        goto free_resources;
+    }
+
+    coordinates = xcb_translate_coordinates_reply(
+        conn, xcb_translate_coordinates(conn, input_focus->focus, root, geometry->x, geometry->y), NULL);
+    if (coordinates == NULL) {
+        LOG("Failed to translate coordinates.\n");
+        goto free_resources;
+    }
+
+    LOG("Found current focus at x = %i / y = %i.\n", coordinates->dst_x, coordinates->dst_y);
+    result->x = coordinates->dst_x;
+    result->y = coordinates->dst_y;
+    success = true;
+
+free_resources:
+    xcb_ungrab_server(conn);
+    free(input_focus);
+    free(coordinates);
+    free(geometry);
+    if (!success) {
+        LOG("Could not position on focused output, trying to position on primary output.\n");
+        set_window_position_primary(result);
+    }
 }
 
 int main(int argc, char *argv[]) {
@@ -360,6 +407,7 @@ int main(int argc, char *argv[]) {
 
     argv0 = argv[0];
 
+    bool position_on_primary = false;
     char *pattern = sstrdup("pango:monospace 8");
     int o, option_index = 0;
     enum { TYPE_ERROR = 0,
@@ -373,9 +421,10 @@ int main(int argc, char *argv[]) {
         {"help", no_argument, 0, 'h'},
         {"message", required_argument, 0, 'm'},
         {"type", required_argument, 0, 't'},
+        {"primary", no_argument, 0, 'p'},
         {0, 0, 0, 0}};
 
-    char *options_string = "b:B:f:m:t:vh";
+    char *options_string = "b:B:f:m:t:vhp";
 
     prompt = i3string_from_utf8("Please do not run this program.");
 
@@ -399,8 +448,11 @@ int main(int argc, char *argv[]) {
             case 'h':
                 free(pattern);
                 printf("i3-nagbar " I3_VERSION "\n");
-                printf("i3-nagbar [-m <message>] [-b <button> <action>] [-B <button> <action>] [-t warning|error] [-f <font>] [-v]\n");
+                printf("i3-nagbar [-m <message>] [-b <button> <action>] [-B <button> <action>] [-t warning|error] [-f <font>] [-v] [-p]\n");
                 return 0;
+            case 'p':
+                position_on_primary = true;
+                break;
             case 'b':
             case 'B':
                 buttons = srealloc(buttons, sizeof(button_t) * (buttoncnt + 1));
@@ -412,8 +464,9 @@ int main(int argc, char *argv[]) {
                        buttons[buttoncnt].action);
                 buttoncnt++;
                 printf("now %d buttons\n", buttoncnt);
-                if (optind < argc)
+                if (optind < argc) {
                     optind++;
+                }
                 break;
         }
     }
@@ -422,8 +475,9 @@ int main(int argc, char *argv[]) {
 
     int screens;
     if ((conn = xcb_connect(NULL, &screens)) == NULL ||
-        xcb_connection_has_error(conn))
+        xcb_connection_has_error(conn)) {
         die("Cannot open display");
+    }
 
 /* Place requests for the atoms we need as soon as possible */
 #define xmacro(atom) \
@@ -459,12 +513,13 @@ int main(int argc, char *argv[]) {
     font = load_font(pattern, true);
     set_font(&font);
 
-#if defined(__OpenBSD__)
-    if (pledge("stdio rpath wpath cpath getpw proc exec", NULL) == -1)
-        err(EXIT_FAILURE, "pledge");
-#endif
-
-    xcb_rectangle_t win_pos = get_window_position();
+    /* Default values if we cannot determine the preferred window position. */
+    xcb_rectangle_t win_pos = (xcb_rectangle_t){50, 50, 500, font.height + 2 * MSG_PADDING + BAR_BORDER};
+    if (position_on_primary) {
+        set_window_position_primary(&win_pos);
+    } else {
+        set_window_position_focus(&win_pos);
+    }
 
     xcb_cursor_context_t *cursor_ctx;
     if (xcb_cursor_context_new(conn, root_screen, &cursor_ctx) < 0) {
