@@ -46,6 +46,9 @@ struct status_block {
     i3String *full_text;
     i3String *short_text;
 
+    bool use_short;
+    uint32_t render_length;
+
     char *color;
     char *background;
     char *border;
