@@ -1,7 +1,7 @@
 /*
  * vim:ts=4:sw=4:expandtab
  *
- * i3 - an improved dynamic tiling window manager
+ * i3 - an improved tiling window manager
  * © 2009 Michael Stapelberg and contributors (see also: LICENSE)
  *
  * config_parser.h: config parser-related definitions
@@ -35,7 +35,6 @@ struct stack {
 
 struct parser_ctx {
     bool use_nagbar;
-    bool assume_v4;
 
     int state;
     Match current_match;
