@@ -1,7 +1,7 @@
 /*
  * vim:ts=4:sw=4:expandtab
  *
- * i3 - an improved dynamic tiling window manager
+ * i3 - an improved tiling window manager
  * © 2009 Michael Stapelberg and contributors (see also: LICENSE)
  *
  * ipc.c: UNIX domain socket IPC (initialization, client handling, protocol).
@@ -133,7 +133,7 @@ void ipc_send_barconfig_update_event(Barconfig *barconfig);
 /**
  * For the binding events, we send the serialized binding struct.
  */
-void ipc_send_binding_event(const char *event_type, Binding *bind);
+void ipc_send_binding_event(const char *event_type, Binding *bind, const char *modename);
 
 /**
  * Set the maximum duration that we allow for a connection with an unwriteable
