@@ -1,7 +1,7 @@
 /*
  * vim:ts=4:sw=4:expandtab
  *
- * i3 - an improved dynamic tiling window manager
+ * i3 - an improved tiling window manager
  * © 2009 Michael Stapelberg and contributors (see also: LICENSE)
  *
  */
@@ -21,6 +21,7 @@ static xcb_visualtype_t *root_visual_type;
 static double pango_font_red;
 static double pango_font_green;
 static double pango_font_blue;
+static double pango_font_alpha;
 
 static PangoLayout *create_layout_with_dpi(cairo_t *cr) {
     PangoLayout *layout;
@@ -95,14 +96,15 @@ static void draw_text_pango(const char *text, size_t text_len,
     pango_layout_set_wrap(layout, PANGO_WRAP_CHAR);
     pango_layout_set_ellipsize(layout, PANGO_ELLIPSIZE_END);
 
-    if (pango_markup)
+    if (pango_markup) {
         pango_layout_set_markup(layout, text, text_len);
-    else
+    } else {
         pango_layout_set_text(layout, text, text_len);
+    }
 
     /* Do the drawing */
     cairo_set_operator(cr, CAIRO_OPERATOR_SOURCE);
-    cairo_set_source_rgb(cr, pango_font_red, pango_font_green, pango_font_blue);
+    cairo_set_source_rgba(cr, pango_font_red, pango_font_green, pango_font_blue, pango_font_alpha);
     pango_cairo_update_layout(cr, layout);
     pango_layout_get_pixel_size(layout, NULL, &height);
     /* Center the piece of text vertically. */
@@ -130,10 +132,11 @@ static int predict_text_width_pango(const char *text, size_t text_len, bool pang
     gint width;
     pango_layout_set_font_description(layout, savedFont->specific.pango_desc);
 
-    if (pango_markup)
+    if (pango_markup) {
         pango_layout_set_markup(layout, text, text_len);
-    else
+    } else {
         pango_layout_set_text(layout, text, text_len);
+    }
 
     pango_cairo_update_layout(cr, layout);
     pango_layout_get_pixel_size(layout, &width, NULL);
@@ -160,7 +163,7 @@ i3Font load_font(const char *pattern, const bool fallback) {
     font.type = FONT_TYPE_NONE;
     font.pattern = NULL;
 
-    /* No XCB connction, return early because we're just validating the
+    /* No XCB connection, return early because we're just validating the
      * configuration file. */
     if (conn == NULL) {
         return font;
@@ -213,10 +216,11 @@ i3Font load_font(const char *pattern, const bool fallback) {
             info_cookie = xcb_query_font(conn, font.specific.xcb.id);
 
             free(error);
-            if ((error = xcb_request_check(conn, font_cookie)) != NULL)
+            if ((error = xcb_request_check(conn, font_cookie)) != NULL) {
                 errx(EXIT_FAILURE, "Could open neither requested font nor fallbacks "
                                    "(fixed or -misc-*): X11 error %d",
                      error->error_code);
+            }
         }
     }
     free(error);
@@ -225,14 +229,16 @@ i3Font load_font(const char *pattern, const bool fallback) {
     LOG("Using X font %s\n", pattern);
 
     /* Get information (height/name) for this font */
-    if (!(font.specific.xcb.info = xcb_query_font_reply(conn, info_cookie, NULL)))
+    if (!(font.specific.xcb.info = xcb_query_font_reply(conn, info_cookie, NULL))) {
         errx(EXIT_FAILURE, "Could not load font \"%s\"", pattern);
+    }
 
     /* Get the font table, if possible */
-    if (xcb_query_font_char_infos_length(font.specific.xcb.info) == 0)
+    if (xcb_query_font_char_infos_length(font.specific.xcb.info) == 0) {
         font.specific.xcb.table = NULL;
-    else
+    } else {
         font.specific.xcb.table = xcb_query_font_char_infos(font.specific.xcb.info);
+    }
 
     /* Calculate the font height */
     font.height = font.specific.xcb.info->font_ascent + font.specific.xcb.info->font_descent;
@@ -257,8 +263,9 @@ void set_font(i3Font *font) {
  */
 void free_font(void) {
     /* if there is no saved font, simply return */
-    if (savedFont == NULL)
+    if (savedFont == NULL) {
         return;
+    }
 
     free(savedFont->pattern);
     switch (savedFont->type) {
@@ -303,6 +310,7 @@ void set_font_colors(xcb_gcontext_t gc, color_t foreground, color_t background)
             pango_font_red = foreground.red;
             pango_font_green = foreground.green;
             pango_font_blue = foreground.blue;
+            pango_font_alpha = foreground.alpha;
             break;
     }
 }
@@ -338,8 +346,9 @@ static void draw_text_xcb(const xcb_char2b_t *text, size_t text_len, xcb_drawabl
         text_len -= chunk_size;
 
         /* Check if we're done */
-        if (text_len == 0)
+        if (text_len == 0) {
             break;
+        }
 
         /* Advance pos_x based on the predicted text width */
         x += predict_text_width_xcb(chunk, chunk_size);
@@ -403,8 +412,9 @@ static int xcb_query_text_width(const xcb_char2b_t *text, size_t text_len) {
 }
 
 static int predict_text_width_xcb(const xcb_char2b_t *input, size_t text_len) {
-    if (text_len == 0)
+    if (text_len == 0) {
         return 0;
+    }
 
     int width;
     if (savedFont->specific.xcb.table == NULL) {
@@ -425,8 +435,9 @@ static int predict_text_width_xcb(const xcb_char2b_t *input, size_t text_len) {
             if (row < font_info->min_byte1 ||
                 row > font_info->max_byte1 ||
                 col < font_info->min_char_or_byte2 ||
-                col > font_info->max_char_or_byte2)
+                col > font_info->max_char_or_byte2) {
                 continue;
+            }
 
             /* Don't you ask me, how this one works… (Merovius) */
             info = &font_table[((row - font_info->min_byte1) *
