@@ -1,7 +1,7 @@
 /*
  * vim:ts=4:sw=4:expandtab
  *
- * i3 - an improved dynamic tiling window manager
+ * i3 - an improved tiling window manager
  * © 2009 Michael Stapelberg and contributors (see also: LICENSE)
  *
  * config.c: Configuration file (calling the parser (src/config_parser.c) with
@@ -61,12 +61,13 @@ static void free_configuration(void) {
 
     while (!TAILQ_EMPTY(&assignments)) {
         struct Assignment *assign = TAILQ_FIRST(&assignments);
-        if (assign->type == A_TO_WORKSPACE || assign->type == A_TO_WORKSPACE_NUMBER)
+        if (assign->type == A_TO_WORKSPACE || assign->type == A_TO_WORKSPACE_NUMBER) {
             FREE(assign->dest.workspace);
-        else if (assign->type == A_COMMAND)
+        } else if (assign->type == A_COMMAND) {
             FREE(assign->dest.command);
-        else if (assign->type == A_TO_OUTPUT)
+        } else if (assign->type == A_TO_OUTPUT) {
             FREE(assign->dest.output);
+        }
         match_free(&(assign->match));
         TAILQ_REMOVE(&assignments, assign, assignments);
         FREE(assign);
@@ -85,8 +86,9 @@ static void free_configuration(void) {
     while (!TAILQ_EMPTY(&barconfigs)) {
         barconfig = TAILQ_FIRST(&barconfigs);
         FREE(barconfig->id);
-        for (int c = 0; c < barconfig->num_outputs; c++)
+        for (int c = 0; c < barconfig->num_outputs; c++) {
             free(barconfig->outputs[c]);
+        }
 
         while (!TAILQ_EMPTY(&(barconfig->bar_bindings))) {
             struct Barbinding *binding = TAILQ_FIRST(&(barconfig->bar_bindings));
@@ -224,12 +226,14 @@ bool load_configuration(const char *override_configpath, config_load_t load_type
     config.gaps.left = 0;
 
     /* Set default urgency reset delay to 500ms */
-    if (config.workspace_urgency_timer == 0)
+    if (config.workspace_urgency_timer == 0) {
         config.workspace_urgency_timer = 0.5;
+    }
 
     config.focus_wrapping = FOCUS_WRAPPING_ON;
 
     config.tiling_drag = TILING_DRAG_MODIFIER;
+    config.swap_modifier = XCB_KEY_BUT_MASK_SHIFT;
 
     FREE(current_configpath);
     current_configpath = get_config_path(override_configpath, true);
@@ -263,7 +267,6 @@ bool load_configuration(const char *override_configpath, config_load_t load_type
     memset(&stack, '\0', sizeof(struct stack));
     struct parser_ctx ctx = {
         .use_nagbar = (load_type != C_VALIDATE),
-        .assume_v4 = false,
         .stack = &stack,
     };
     SLIST_INIT(&(ctx.variables));
