@@ -1,7 +1,7 @@
 /*
  * vim:ts=4:sw=4:expandtab
  *
- * i3 - an improved dynamic tiling window manager
+ * i3 - an improved tiling window manager
  * © 2009 Michael Stapelberg and contributors (see also: LICENSE)
  *
  * log.c: Logging functions.
@@ -94,9 +94,9 @@ static void store_log_markers(void) {
  */
 void init_logging(void) {
     if (!errorfilename) {
-        if (!(errorfilename = get_process_filename("errorlog")))
+        if (!(errorfilename = get_process_filename("errorlog"))) {
             fprintf(stderr, "Could not initialize errorlog\n");
-        else {
+        } else {
             errorfile = fopen(errorfilename, "w");
             if (!errorfile) {
                 fprintf(stderr, "Could not initialize errorlog on %s: %s\n",
@@ -121,10 +121,11 @@ void init_logging(void) {
     /* Start SHM logging if shmlog_size is > 0. shmlog_size is SHMLOG_SIZE by
      * default on development versions, and 0 on release versions. If it is
      * not > 0, the user has turned it off, so let's close the logbuffer. */
-    if (shmlog_size > 0 && logbuffer == NULL)
+    if (shmlog_size > 0 && logbuffer == NULL) {
         open_logbuffer();
-    else if (shmlog_size <= 0 && logbuffer)
+    } else if (shmlog_size <= 0 && logbuffer) {
         close_logbuffer();
+    }
     atexit(purge_zerobyte_logfile);
 }
 
@@ -137,7 +138,11 @@ void open_logbuffer(void) {
      * For 512 MiB of RAM this will lead to a 5 MiB log buffer.
      * At the moment (2011-12-10), no testcase leads to an i3 log
      * of more than ~ 600 KiB. */
-    logbuffer_size = min(physical_mem_bytes * 0.01, shmlog_size);
+    logbuffer_size = shmlog_size;
+    if (physical_mem_bytes * 0.01 < (long long)shmlog_size) {
+        logbuffer_size = physical_mem_bytes * 0.01;
+    }
+
 #if defined(__FreeBSD__)
     sasprintf(&shmlogname, "/tmp/i3-log-%d", getpid());
 #else
@@ -288,8 +293,9 @@ static void vlog(const bool print, const char *fmt, va_list args) {
 
         store_log_markers();
 
-        if (print)
+        if (print) {
             fwrite(message, len, 1, stdout);
+        }
 
         log_broadcast_to_clients(message, len);
     }
@@ -303,8 +309,9 @@ static void vlog(const bool print, const char *fmt, va_list args) {
 void verboselog(char *fmt, ...) {
     va_list args;
 
-    if (!logbuffer && !verbose)
+    if (!logbuffer && !verbose) {
         return;
+    }
 
     va_start(args, fmt);
     vlog(verbose, fmt, args);
@@ -323,6 +330,9 @@ void errorlog(char *fmt, ...) {
     va_end(args);
 
     /* also log to the error logfile, if opened */
+    if (!errorfile) {
+        return;
+    }
     va_start(args, fmt);
     vfprintf(errorfile, fmt, args);
     fflush(errorfile);
@@ -338,8 +348,9 @@ void errorlog(char *fmt, ...) {
 void debuglog(char *fmt, ...) {
     va_list args;
 
-    if (!logbuffer && !(debug_logging))
+    if (!logbuffer && !(debug_logging)) {
         return;
+    }
 
     va_start(args, fmt);
     vlog(debug_logging, fmt, args);
@@ -355,15 +366,18 @@ void purge_zerobyte_logfile(void) {
     struct stat st;
     char *slash;
 
-    if (!errorfilename)
+    if (!errorfilename) {
         return;
+    }
 
     /* don't delete the log file if it contains something */
-    if ((stat(errorfilename, &st)) == -1 || st.st_size > 0)
+    if ((stat(errorfilename, &st)) == -1 || st.st_size > 0) {
         return;
+    }
 
-    if (unlink(errorfilename) == -1)
+    if (unlink(errorfilename) == -1) {
         return;
+    }
 
     if ((slash = strrchr(errorfilename, '/')) != NULL) {
         *slash = '\0';
