@@ -1,7 +1,7 @@
 /*
  * vim:ts=4:sw=4:expandtab
  *
- * i3 - an improved dynamic tiling window manager
+ * i3 - an improved tiling window manager
  * © 2009 Michael Stapelberg and contributors (see also: LICENSE)
  *
  * xcb.c: Helper functions for easier usage of XCB
@@ -49,8 +49,9 @@ xcb_window_t create_window(xcb_connection_t *conn, Rect dims,
     xcb_change_window_attributes(conn, result, XCB_CW_CURSOR, cursor_values);
 
     /* Map the window (= make it visible) */
-    if (map)
+    if (map) {
         xcb_map_window(conn, result);
+    }
 
     return result;
 }
@@ -62,8 +63,9 @@ xcb_window_t create_window(xcb_connection_t *conn, Rect dims,
  */
 void fake_absolute_configure_notify(Con *con) {
     xcb_rectangle_t absolute;
-    if (con->window == NULL)
+    if (con->window == NULL) {
         return;
+    }
 
     absolute.x = con->rect.x + con->window_rect.x;
     absolute.y = con->rect.y + con->window_rect.y;
@@ -119,12 +121,14 @@ void xcb_set_window_rect(xcb_connection_t *conn, xcb_window_t window, Rect r) {
  *
  */
 xcb_atom_t xcb_get_preferred_window_type(xcb_get_property_reply_t *reply) {
-    if (reply == NULL || xcb_get_property_value_length(reply) == 0)
+    if (reply == NULL || xcb_get_property_value_length(reply) == 0) {
         return XCB_NONE;
+    }
 
     xcb_atom_t *atoms;
-    if ((atoms = xcb_get_property_value(reply)) == NULL)
+    if ((atoms = xcb_get_property_value(reply)) == NULL) {
         return XCB_NONE;
+    }
 
     for (int i = 0; i < xcb_get_property_value_length(reply) / (reply->format / 8); i++) {
         if (atoms[i] == A__NET_WM_WINDOW_TYPE_NORMAL ||
@@ -149,16 +153,20 @@ xcb_atom_t xcb_get_preferred_window_type(xcb_get_property_reply_t *reply) {
  *
  */
 bool xcb_reply_contains_atom(xcb_get_property_reply_t *prop, xcb_atom_t atom) {
-    if (prop == NULL || xcb_get_property_value_length(prop) == 0)
+    if (prop == NULL || xcb_get_property_value_length(prop) == 0) {
         return false;
+    }
 
     xcb_atom_t *atoms;
-    if ((atoms = xcb_get_property_value(prop)) == NULL)
+    if ((atoms = xcb_get_property_value(prop)) == NULL) {
         return false;
+    }
 
-    for (int i = 0; i < xcb_get_property_value_length(prop) / (prop->format / 8); i++)
-        if (atoms[i] == atom)
+    for (int i = 0; i < xcb_get_property_value_length(prop) / (prop->format / 8); i++) {
+        if (atoms[i] == atom) {
             return true;
+        }
+    }
 
     return false;
 }
@@ -193,14 +201,16 @@ xcb_visualid_t get_visualid_by_depth(uint16_t depth) {
 
     depth_iter = xcb_screen_allowed_depths_iterator(root_screen);
     for (; depth_iter.rem; xcb_depth_next(&depth_iter)) {
-        if (depth_iter.data->depth != depth)
+        if (depth_iter.data->depth != depth) {
             continue;
+        }
 
         xcb_visualtype_iterator_t visual_iter;
 
         visual_iter = xcb_depth_visuals_iterator(depth_iter.data);
-        if (!visual_iter.rem)
+        if (!visual_iter.rem) {
             continue;
+        }
         return visual_iter.data->visual_id;
     }
     return 0;
@@ -227,8 +237,9 @@ void xcb_remove_property_atom(xcb_connection_t *conn, xcb_window_t window, xcb_a
     xcb_get_property_reply_t *reply =
         xcb_get_property_reply(conn,
                                xcb_get_property(conn, false, window, property, XCB_GET_PROPERTY_TYPE_ANY, 0, 4096), NULL);
-    if (reply == NULL || xcb_get_property_value_length(reply) == 0)
+    if (reply == NULL || xcb_get_property_value_length(reply) == 0) {
         goto release_grab;
+    }
     xcb_atom_t *atoms = xcb_get_property_value(reply);
     if (atoms == NULL) {
         goto release_grab;
@@ -239,8 +250,9 @@ void xcb_remove_property_atom(xcb_connection_t *conn, xcb_window_t window, xcb_a
         const int current_size = xcb_get_property_value_length(reply) / (reply->format / 8);
         xcb_atom_t values[current_size];
         for (int i = 0; i < current_size; i++) {
-            if (atoms[i] != atom)
+            if (atoms[i] != atom) {
                 values[num++] = atoms[i];
+            }
         }
 
         xcb_change_property(conn, XCB_PROP_MODE_REPLACE, window, property, XCB_ATOM_ATOM, 32, num, values);
